<?php

declare(strict_types = 1);

namespace Drupal\rdf_meta_entity\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\meta_entity\Entity\MetaEntity;
use Drupal\meta_entity\Entity\MetaEntityInterface;

/**
 * Defines the meta entity content entity class with SPARQL storage backend.
 *
 * @ContentEntityType(
 *   id = "rdf_meta_entity",
 *   label = @Translation("RDF meta entity"),
 *   label_collection = @Translation("RDF meta entities"),
 *   bundle_label = @Translation("RDF meta entity type"),
 *   handlers = {
 *     "storage" = "\Drupal\sparql_entity_storage\SparqlEntityStorage",
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *     "access" = "Drupal\meta_entity\MetaEntityAccessControlHandler",
 *   },
 *   bundle_entity_type = "rdf_meta_entity_type",
 *   admin_permission = "administer rdf meta entity",
 *   field_ui_base_route = "entity.rdf_meta_entity_type.edit_form",
 *   entity_keys = {
 *     "id" = "id",
 *     "bundle" = "type",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   },
 * )
 */
class RdfMetaEntity extends MetaEntity {

  /**
   * {@inheritdoc}
   */
  public static function loadOrCreate(string $meta_entity_bundle, ContentEntityInterface $target_entity): MetaEntityInterface {
    return self::loadOrCreateHelper('rdf_meta_entity', $meta_entity_bundle, $target_entity);
  }

}
